@@ -536,16 +536,15 @@ def get_address_object(obj_id, timeout=None):
 
     :raises requests.ConnectionError: если не удалось соединиться с сервером ГАР
     """
-    assert obj_id is not None
+    result = None
 
-    response = server.get('/addrobj/{}/'.format(obj_id), timeout=timeout)
+    if obj_id:
+        response = server.get('/addrobj/{}/'.format(obj_id), timeout=timeout)
 
-    if response.status_code == http_client.OK:
-        response_data = response.json()
-        mapped_data = map_object_data(AddressObjectMapper, response_data)
-        result = AddressObject(**mapped_data)
-    else:
-        result = None
+        if response.status_code == http_client.OK:
+            response_data = response.json()
+            mapped_data = map_object_data(AddressObjectMapper, response_data)
+            result = AddressObject(**mapped_data)
 
     return result
 
